Summary:       Library for arbitrary precision arithmetic
Name:          gmp
Version:       6.3.0
Release:       1%{?dist}
License:       LGPLv3+ or GPLv2+
URL:           https://gmplib.org/
Source0:       https://gmplib.org/download/gmp/gmp-%{version}.tar.xz
Patch3000:     gmp-intel-cet.patch

BuildRequires: autoconf automake libtool
BuildRequires: make gcc gcc-c++ git
BuildRequires: fipscheck

%description
GMP is a free library for arbitrary precision arithmetic, operating on signed integers,
rational numbers, and floating-point numbers. There is no practical limit to the precision
except the ones implied by the available memory in the machine GMP runs on. GMP has a rich
set of functions, and the functions have a regular interface.
The main target applications for GMP are cryptography applications and research, Internet
security applications, algebra systems, computational algebra research, etc.
GMP is carefully designed to be as fast as possible, both for small operands and for huge operands.
The speed is achieved by using fullwords as the basic arithmetic type, by using fast algorithms,
with highly optimised assembly code for the most common inner loops for a lot of CPUs,
and by a general emphasis on speed.

There are several categories of functions in GMP:
1.High-level signed integer arithmetic functions (mpz).
2.High-level rational arithmetic functions (mpq).
3.High-level floating-point arithmetic functions (mpf).
4.C++ class based interface to all of the above.
5.Low-level positive-integer, hard-to-use, very low overhead functions (mpn).


%package c++
Summary:       C++ bindings for gmp
Requires:      %{name} = %{version}-%{release}

%description c++
Bindings for using gmp in C++ applications.


%package devel
Summary:       Development files for gmp
Requires:      %{name} = %{version}-%{release}
Requires:      %{name}-c++ = %{version}-%{release}

%description devel
Libraries, header files and documentation for developing  applications with gmp.


%package static
Summary:       Static libraries for gmp
Requires:      %{name}-devel = %{version}-%{release}

%description static
Static libraries for applications using gmp.


%prep
%autosetup -S git


%build
autoreconf -ifv
export CCAS="gcc -c -Wa,--noexecstack"
%configure --enable-cxx --enable-fat

sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|-lstdc++ -lm|-lstdc++|' -i libtool
%make_build


%define __spec_install_post \
    %{?__debug_package:%{__debug_install_post}} \
    %{__arch_install_post} \
    %{__os_install_post} \
    fipshmac -d %{buildroot}%{_libdir} %{buildroot}%{_libdir}/libgmp.so.10.* \
    file=`basename %{buildroot}%{_libdir}/libgmp.so.10.*.hmac` && \
        mv %{buildroot}%{_libdir}/$file %{buildroot}%{_libdir}/.$file && \
        ln -s .$file %{buildroot}%{_libdir}/.libgmp.so.10.hmac

%install
%make_install 
rm -f %{buildroot}%{_libdir}/lib{gmp,mp,gmpxx}.la
rm -f %{buildroot}%{_infodir}/dir
ln -sf libgmpxx.so.4 %{buildroot}%{_libdir}/libgmpxx.so


%check
export LD_LIBRARY_PATH=`pwd`/.libs
%make_build check


%files
%license COPYING COPYING.LESSERv3 COPYINGv2 COPYINGv3
%doc NEWS README
%{_libdir}/libgmp.so.*
%{_libdir}/.libgmp.so.*.hmac

%files c++
%{_libdir}/libgmpxx.so.*

%files devel
%{_libdir}/libgmp.so
%{_libdir}/libgmpxx.so
%{_libdir}/pkgconfig/gmp.pc
%{_libdir}/pkgconfig/gmpxx.pc
%{_includedir}/*.h
%{_infodir}/gmp.info*

%files static
%{_libdir}/libgmp.a
%{_libdir}/libgmpxx.a


%changelog
* Mon Jan 15 2024 Miaojun Dong <zoedong@tencent.com> - 6.3.0-1
- Upgrade to version 6.3.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.2.1-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 20 2022 rockerzhu <rockerzhu@tencent.com> - 6.2.1-1
- Initial build
